@@ -1,41 +1,16 @@
 package MooseX::MethodAttributes::Role::Meta::Class;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 # ABSTRACT: metaclass role for storing code attributes
 
 use Moose::Role;
 use Moose::Util qw/find_meta does_role/;
-use MooseX::Types::Moose qw/HashRef ArrayRef Str Int/;
 
 use namespace::clean -except => 'meta';
 
-has _method_attribute_map => (
-    is        => 'ro',
-    isa       => HashRef[ArrayRef[Str]],
-    lazy      => 1,
-    default   => sub { +{} },
-);
-
-has _method_attribute_list => (
-    is      => 'ro',
-    isa     => ArrayRef[Int],
-    lazy    => 1,
-    default => sub { [] },
-);
-
-
-sub register_method_attributes {
-    my ($self, $code, $attrs) = @_;
-    push @{ $self->_method_attribute_list }, 0 + $code;
-    $self->_method_attribute_map->{ 0 + $code } = $attrs;
-    return;
-}
-
-
-sub get_method_attributes {
-    my ($self, $code) = @_;
-    return $self->_method_attribute_map->{ 0 + $code } || [];
-}
+with qw/
+    MooseX::MethodAttributes::Role::Meta::Map
+/;
 
 
 sub get_method_with_attributes_list {
@@ -133,22 +108,10 @@ MooseX::MethodAttributes::Role::Meta::Class - metaclass role for storing code at
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 METHODS
 
-=head2 register_method_attributes ($code, $attrs)
-
-Register a list of attributes for a code reference.
-
-
-
-=head2 get_method_attributes ($code)
-
-Get a list of attributes associated with a coderef.
-
-
-
 =head2 get_method_with_attributes_list
 
 Gets the list of meta methods for local methods of this class that have
