@@ -1,7 +1,7 @@
 package RoleWithAttributes;
-our $VERSION = '0.16_01';
+our $VERSION = '0.12';
 
-use MooseX::MethodAttributes::Role;
+use Moose::Role -traits => 'MethodAttributes';
 use namespace::clean -except => 'meta';
 
 sub foo : AnAttr { 'foo' }
